@@ -15,7 +15,7 @@ from ws4py.client.threadedclient import WebSocketClient
 
 from . import error
 
-_DEBUG = True
+_DEBUG = False
 
 RAMP_ENABLED = ['HBO_App',
                 '18a8aeaa-8e3d-4c24-b05d-da68394a3476_1',
@@ -334,6 +334,16 @@ class RampSubprotocol(BaseSubprotocol):
         self._send_ramp({RAMP_ATTR_TYPE: RAMP_TYPE_VOLUME,
                          RAMP_ATTR_VOLUME: volume})
 
+    def volume_up(self):
+        """ Increases volume. """
+        if self.volume < 1:
+            self.set_volume(min(self.volume+.1, 1))
+
+    def volume_down(self):
+        """ Decreases volume. """
+        if self.volume > 0:
+            self.set_volume(max(self.volume-.1, 0))
+
     def refresh(self):
         """ Refresh data at the RAMP-target. """
         self._send_ramp({RAMP_ATTR_TYPE: RAMP_TYPE_INFO})
